# -*- coding: utf-8 -*-
# Part of Odoo. See LICENSE file for full copyright and licensing details.

from . import common
from . import test_mailing_internals
from . import test_mailing_retry
from . import test_mailing_sms_ab_testing
